/*
 * Copyright (c) 2016-2019, National Institute of Informatics
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.gakunin.idp.attribute.filter.context;

import java.util.HashMap;
import java.util.Map;
import java.util.Set;

import javax.annotation.concurrent.NotThreadSafe;

import org.opensaml.messaging.context.BaseContext;

/**
 * Coordinates data between the filter implementation and the MatchFunctor implementations of uApproveJP.
 * 
 * <p>
 * This should be considered a private API limited to plugin implementations.
 * </p>
 */
@NotThreadSafe
public final class AttributeFilterOptionalContext extends BaseContext {

    /** whether the option attribute values are prohibited to be released. */
    private boolean mandatoryValueMode = false;

    /**
     * Get whether the option attribute values are prohibited to be released.
     *
     * @return whether the option attribute values are prohibited to be released.
     */
    public boolean isMandatoryValueMode() {
        return mandatoryValueMode;
    }

    /**
     * Set whether the option attribute values are prohibited to be released.
     *
     * @param flag whether the option attribute values are prohibited to be released.
     */
    public void setMandatoryValueMode(final boolean flag) {
        mandatoryValueMode = flag;
    }
}
